@@ -5,21 +5,26 @@ from pathlib import Path
 def test_page(url: str, file=None):
     try:
         request = requests.get(url)
-        if request.status_code == 200:
+        if request.ok:
             if file:
                 file = Path(file)
-                print(url, 'Web site exists', file.name)
+                print(file.name, end=" ")
                 with file.open("wb+") as writer:
                     writer.write(request.content)
-            else:
-                print(url, 'Web site exists')
-            return True
+            if 200 <= request.status_code < 300:
+                print(request.status_code, url, 'Web site exists!')
+            if 300 <= request.status_code < 400:
+                print(request.status_code, url, 'Request was redirected')
+            return request.status_code, request.reason
+        elif request.status_code in [401, 402, 403, 410, 429]:
+            print(request.status_code, url, 'Access denied!')
+            return request.status_code, request.reason
         else:
-            print(url, 'Web site does not exist')
-            return False
+            print(url, 'Web site does not exist!')
+            return 0, None
     except requests.exceptions.ConnectionError:
-        print(url, 'Web site does not exist')
-        return False
+        print(url, 'Connection error')
+        return 0, None
 
 
 def test_file(fname: str):
